VERSION 1.0 CLASS
BEGIN
  MultiUse = -1  'True
  Persistable = 0  'NotPersistable
  DataBindingBehavior = 0  'vbNone
  DataSourceBehavior  = 0  'vbNone
  MTSTransactionMode  = 0  'NotAnMTSObject
END
Attribute VB_Name = "XLWorker"
Attribute VB_GlobalNameSpace = False
Attribute VB_Creatable = True
Attribute VB_PredeclaredId = False
Attribute VB_Exposed = True
'----------------------
'XLWroker : This is a wrapper class for exporting data into to excel workbook or a excel template

'----------------------
Option Explicit

Dim m_xlApp As Excel.Application
Dim m_xlSheet As Excel.Worksheet
Dim m_xlBook As Excel.Workbook

'---------------------------------------------------------------
'Name : CellAddComment
'Description : Use this method if you want to add comments to a cell
'Parameters : row, col. and the comment
'ReturnValue: True if successful, false otherwise
'---------------------------------------------------------------
Public Function CellAddComment(lngRow As Long, lngCol As Long, strComment As String) As Boolean
On Error GoTo ErrHandler

If Not ValidRowCol(lngRow, lngCol) Then
    CellAddComment = False
    Exit Function
End If
m_xlSheet.Cells(lngRow, lngCol).AddComment strComment
CellAddComment = True

Exit Function
ErrHandler:
    CellAddComment = False
    ShowError "Error in AddCommentToCell (" & Err.Number & ") " & Err.Description
End Function


'---------------------------------------------------------------
'Name : CellAddFormula
'Description : Use this method if you want assign a formula to a cell
'Parameters : row, col. and the formula
'ReturnValue: True if successful, false otherwise
'---------------------------------------------------------------
Public Function CellSetFormula(lngRow As Long, lngCol As Long, strFormula As String) As Boolean
On Error GoTo ErrHandler

If Not ValidRowCol(lngRow, lngCol) Then
    CellSetFormula = False
    Exit Function
End If

If Left(strFormula, 1) <> "=" Then
    strFormula = "=" & Trim$(strFormula)
End If

m_xlSheet.Cells(lngRow, lngCol).Formula = strFormula

CellSetFormula = True
Exit Function
ErrHandler:
    CellSetFormula = False
    ShowError "XLWorker: Error in CellSetFormula (" & Err.Number & ") " & Err.Description
End Function


'---------------------------------------------------------------
'Name : CellSetFont
'Description : Use this method if you want to a different font from the default to a cell
'Parameters : row, col. , fontname and font size
'ReturnValue: True if successful, false otherwise
'---------------------------------------------------------------
Public Function CellSetFont(lngRow As Long, lngCol As Long, strFontName As String, lngFontSize As Long) As Boolean
On Error GoTo ErrHandler

If Not ValidRowCol(lngRow, lngCol) Then
    CellSetFont = False
    Exit Function
End If

With m_xlSheet.Cells(lngRow, lngCol).Font
    .Name = strFontName
    .Size = lngFontSize
End With

CellSetFont = True
Exit Function
ErrHandler:
    CellSetFont = False
    ShowError "XLWorker: Error in CellSetFont (" & Err.Number & ") " & Err.Description
End Function

'---------------------------------------------------------------
'Name : CellSetNumericText
'Description : Use this method if you want to assign a numeric value to a cell
'Parameters : row, col. , numeric value and the optional forecolor
'ReturnValue: True if successful, false otherwise
'---------------------------------------------------------------
Public Function CellSetNumericText(lngRow As Long, lngCol As Long, strCellText As Variant, Optional ForeColor As ColorConstants) As Boolean
On Error GoTo ErrHandler
Dim intDecimal As Integer

If Not ValidRowCol(lngRow, lngCol) Then
    CellSetNumericText = False
    Exit Function
End If

If IsNumeric(strCellText) Then
    intDecimal = InStr(strCellText, ".")
    
    If intDecimal > 0 Then
        If Len(Mid(strCellText, intDecimal, Len(strCellText) - intDecimal)) = 2 Then
        m_xlSheet.Cells(lngRow, lngCol).NumberFormat = "#0.00"
        Else
        m_xlSheet.Cells(lngRow, lngCol).NumberFormat = "#0.0000"
        End If
    End If
    m_xlSheet.Cells(lngRow, lngCol).Value = strCellText
    
    If Not IsMissing(ForeColor) Then
      m_xlSheet.Cells(lngRow, lngCol).Font.Color = ForeColor
    End If
    
    CellSetNumericText = True
Else
    ShowError "CellSetNumericText should be used to set Numeric Values only.."
    CellSetNumericText = False
End If

Exit Function
ErrHandler:
    CellSetNumericText = False
    ShowError "XLWorker: Error in CellSetNumericText (" & Err.Number & ") " & Err.Description
End Function

'---------------------------------------------------------------
'Name : OpenExcel
'Description : Use this to initialize the Object
'Parameters : NA
'ReturnValue: True if successful, false otherwise
'---------------------------------------------------------------
Public Function OpenExcel() As Boolean
On Error GoTo ErrHandler

    
    ' Clear Err object in case error occurred.
    Err.Clear
    On Error Resume Next
    'get an xl object if it is already running
    Set m_xlApp = GetObject(, "Excel.Application")
    
    'if excel is not available create one
    If Err.Number <> 0 Then
        On Error GoTo ErrHandler
        Set m_xlApp = CreateObject("Excel.Application")
    End If
    
    Set m_xlBook = m_xlApp.Workbooks.Add
    Set m_xlSheet = m_xlBook.Worksheets(1)

OpenExcel = True
Exit Function
ErrHandler:
    OpenExcel = False
    ShowError "XLWorker: Error in OpenExcel (" & Err.Number & ") " & Err.Description
End Function


'---------------------------------------------------------------
'Name : CloseExcel
'Description : Use this method as a teardown
'Parameters : NA
'ReturnValue: True if successful, false otherwise
'---------------------------------------------------------------
Public Function CloseExcel() As Boolean
On Error GoTo ErrHandler

    Set m_xlSheet = Nothing
    Set m_xlBook = Nothing
    Set m_xlApp = Nothing
    
CloseExcel = True
Exit Function
ErrHandler:
    CloseExcel = False
    ShowError "XLWorker: Error in CloseExcel (" & Err.Number & ") " & Err.Description
End Function
'---------------------------------------------------------------
'Name : OpenTemplate
'Description : Use this method if you want to open a pre-defined template
'Parameters : template file with full path
'ReturnValue: True if successful, false otherwise
'---------------------------------------------------------------
Public Function OpenTemplate(strTemplateFile As String) As Boolean
On Error GoTo ErrHandler

If strTemplateFile = "" Then
    OpenTemplate = False
     ShowError "Template file cannot be blank"
    Exit Function
End If

If UCase(strTemplateFile) <> UCase(Dir(strTemplateFile)) Then
    OpenTemplate = False
      ShowError "Couldnot find template file-->" & strTemplateFile
    Exit Function
End If

' Clear Err object in case error occurred.
Err.Clear
On Error Resume Next
'get an xl object if it is already running
Set m_xlApp = GetObject(, "Excel.Application")
    
'if excel is not available create one
If Err.Number <> 0 Then Set m_xlApp = CreateObject("Excel.Application")

On Error GoTo ErrHandler

m_xlApp.Workbooks.Open strTemplateFile

OpenTemplate = True
Exit Function
ErrHandler:
    OpenTemplate = False
    ShowError "XLWorker: Error in OpenTemplate (" & Err.Number & ") " & Err.Description
End Function

'---------------------------------------------------------------
'Name : SetFooter
'Description : Use this method if you want to set left/center/right footer to the sheet
'Parameters : left footer, center footer, right footer
'ReturnValue: True if successful, false otherwise
'---------------------------------------------------------------
Public Function SetFooter(Optional pstrLeftFooter As String, Optional pstrCenterFooter As String, Optional pstrRightFooter As String) As Boolean
On Error GoTo ErrHandler

With m_xlBook

    If IsMissing(pstrLeftFooter) Then
        .ActiveSheet.PageSetup.LeftFooter = "  "
    Else
        .ActiveSheet.PageSetup.LeftFooter = pstrLeftFooter
    End If
    
    If IsMissing(pstrCenterFooter) Then
        .ActiveSheet.PageSetup.CenterFooter = " "
    Else
        .ActiveSheet.PageSetup.CenterFooter = pstrCenterFooter
    End If
     
    If IsMissing(pstrRightFooter) Then
        .ActiveSheet.PageSetup.RightFooter = " "
    Else
        .ActiveSheet.PageSetup.RightFooter = pstrRightFooter
    End If
End With

SetFooter = True
Exit Function
ErrHandler:
    SetFooter = False
    ShowError "XLWorker: Error in SetFooter (" & Err.Number & ") " & Err.Description
End Function

'---------------------------------------------------------------
'Name : SetHeader
'Description : Use this method if you want to add headers to the sheet
'Parameters : header and the fontsize
'ReturnValue: True if successful, false otherwise
'---------------------------------------------------------------
Public Function SetHeader(pstrCenterHeader As String, fntSize As Long) As Boolean

'setting up page headers..

'set as BOLD
'set as center aligned
'also set the fontsize specified
m_xlBook.ActiveSheet.PageSetup.CenterHeader = "&B " & "&C " & "&" & fntSize & pstrCenterHeader & "&B " & "&C "


End Function


'---------------------------------------------------------------
'Name : RowSetText
'Description : Use this method if you want to stuff a a row using a variant array
'Parameters : row and the variant array of data
'ReturnValue: True if successful, false otherwise
'---------------------------------------------------------------
Public Function RowSetText(ByVal lngRow As Long, ByVal varRowData As Variant) As Boolean
On Error GoTo ErrHandler

Dim MaxCols As Integer
Dim lngCol As Long
Dim strText As String

If Not ValidRowCol(lngRow, 1) Then
    RowSetText = False
    Exit Function
End If

MaxCols = UBound(varRowData) + 1

For lngCol = 1 To MaxCols

  strText = varRowData(lngCol - 1)
  If Not (CellSetText(lngRow, lngCol, strText)) Then
    RowSetText = False
    Exit Function
  End If
  
Next
  
RowSetText = True
Exit Function
ErrHandler:
    RowSetText = False
    ShowError "XLWorker: Error in SetRowText (" & Err.Number & ") " & Err.Description
End Function

'---------------------------------------------------------------
'Name : CellSetText
'Description : Use this method if you want to assign text/date values to a cell
'Parameters : row, col. , cell text and fore color
'ReturnValue: True if successful, false otherwise
'---------------------------------------------------------------
Public Function CellSetText(lngRow As Long, lngCol As Long, strCellText As Variant, Optional ForeColor As ColorConstants) As Boolean
On Error GoTo ErrHandler

Dim intDecPosition As Integer
  
If Not ValidRowCol(lngRow, lngCol) Then
    CellSetText = False
    Exit Function
End If
  
   
    If IsDate(Trim(strCellText)) Then
        m_xlSheet.Cells(lngRow, lngCol).Value = strCellText
    Else
        If Left(strCellText, 2) = "LC" Then strCellText = Right(strCellText, Len(strCellText) - 2)
        m_xlSheet.Cells(lngRow, lngCol).Value = "'" & strCellText
        
    End If


If Not IsMissing(ForeColor) Then
      m_xlSheet.Cells(lngRow, lngCol).Font.Color = ForeColor
End If
  
CellSetText = True
Exit Function
ErrHandler:
    CellSetText = False
    ShowError "XLWorker: Error in SetCellText (" & Err.Number & ") " & Err.Description
End Function


'---------------------------------------------------------------
'Name : RangeSetBorder
'Description : Use this method if you set border to a range of cells
'Parameters : starting cell, ending cell
'ReturnValue: True if successful, false otherwise
'---------------------------------------------------------------
Public Function RangeSetBorder(cell1 As String, cell2 As String) As Boolean
On Error GoTo ErrHandler

  m_xlSheet.Range(cell1, cell2).BorderAround , xlThin, xlColorIndexAutomatic
  m_xlSheet.Range(cell1 & ":" & cell2).Columns.AutoFit
  
RangeSetBorder = True
Exit Function
ErrHandler:
    RangeSetBorder = False
    ShowError "XLWorker: Error in SetBorder (" & Err.Number & ") " & Err.Description
End Function

'---------------------------------------------------------------
'Name : RowAutoFit
'Description : Use this method if you want to set the row's autofit property
'Parameters : row number
'ReturnValue: True if successful, false otherwise
'---------------------------------------------------------------
Public Function RowAutoFit(lngRow As Long) As Boolean
On Error GoTo ErrHandler

If Not ValidRowCol(lngRow, 1) Then
    RowAutoFit = False
    Exit Function
End If

  m_xlSheet.Rows(lngRow).AutoFit
  
RowAutoFit = True
Exit Function
ErrHandler:
    RowAutoFit = False
    ShowError "XLWorker: Error in SetAutoFit (" & Err.Number & ") " & Err.Description
End Function
Private Sub ShowError(strErr As String)
MsgBox strErr, vbCritical, App.ProductName
End Sub

'---------------------------------------------------------------
'Name : ShowExcel
'Description : Use this method display the excel application to the user
'Parameters :
'ReturnValue: True if successful, false otherwise
'---------------------------------------------------------------
Public Function ShowExcel() As Boolean
On Error GoTo ErrHandler
  
  m_xlApp.Visible = True
  
ShowExcel = True
Exit Function
ErrHandler:
    ShowExcel = False
    ShowError "XLWorker: Error in ShowExcel (" & Err.Number & ") " & Err.Description
End Function


'---------------------------------------------------------------
'Name : ValidRowCol
'Description : Use this method to validate the row/col
'Parameters : row, col. and the comment
'ReturnValue: True if successful, false otherwise
'---------------------------------------------------------------
Private Function ValidRowCol(lngRow As Long, lngCol As Long) As Boolean
On Error GoTo ErrHandler

If IsNumeric(lngRow) And IsNumeric(lngCol) Then
    If lngRow > 0 And lngCol > 0 Then
        ValidRowCol = True
        Exit Function
    End If
End If

ValidRowCol = False
ShowError "Invalid Row number/Col number supplied to the function"
Exit Function
ErrHandler:
    ValidRowCol = False
    ShowError "XLWorker: Error in ValidRowCol (" & Err.Number & ") " & Err.Description
End Function


